@@ -1,7 +1,7 @@
 use schemars::JsonSchema;
 use serde::{Deserialize, Serialize};
 
-use crate::{order::OrderData, derivative::DerivativeOrder, spot::SpotOrder, route::InjectiveRoute};
+use crate::{derivative::DerivativeOrder, order::OrderData, route::InjectiveRoute, spot::SpotOrder};
 use cosmwasm_std::{Addr, Coin, CosmosMsg, CustomMsg};
 
 #[derive(Serialize, Deserialize, Clone, Debug, PartialEq, JsonSchema)]
@@ -80,7 +80,6 @@ pub enum InjectiveMsg {
         spot_orders_to_create: Vec<SpotOrder>,
         derivative_orders_to_create: Vec<DerivativeOrder>,
     },
-
 }
 
 pub fn create_deposit_msg(sender: String, subaccount_id: String, amount: Coin) -> CosmosMsg<InjectiveMsgWrapper> {
@@ -92,7 +91,7 @@ pub fn create_deposit_msg(sender: String, subaccount_id: String, amount: Coin) -
             amount,
         },
     }
-        .into()
+    .into()
 }
 
 pub fn create_withdraw_msg(sender: String, subaccount_id: String, amount: Coin) -> CosmosMsg<InjectiveMsgWrapper> {
@@ -104,7 +103,7 @@ pub fn create_withdraw_msg(sender: String, subaccount_id: String, amount: Coin)
             amount,
         },
     }
-        .into()
+    .into()
 }
 
 pub fn create_subaccount_transfer_msg(
@@ -122,10 +121,15 @@ pub fn create_subaccount_transfer_msg(
             amount,
         },
     }
-        .into()
+    .into()
 }
 
-pub fn create_external_transfer_msg(sender: String, source_subaccount_id: String, destination_subaccount_id: String, amount: Coin) -> CosmosMsg<InjectiveMsgWrapper> {
+pub fn create_external_transfer_msg(
+    sender: String,
+    source_subaccount_id: String,
+    destination_subaccount_id: String,
+    amount: Coin,
+) -> CosmosMsg<InjectiveMsgWrapper> {
     InjectiveMsgWrapper {
         route: InjectiveRoute::Exchange,
         msg_data: InjectiveMsg::ExternalTransfer {
@@ -135,7 +139,7 @@ pub fn create_external_transfer_msg(sender: String, source_subaccount_id: String
             amount,
         },
     }
-        .into()
+    .into()
 }
 
 pub fn create_spot_market_order_msg(sender: String, order: SpotOrder) -> CosmosMsg<InjectiveMsgWrapper> {
@@ -143,7 +147,7 @@ pub fn create_spot_market_order_msg(sender: String, order: SpotOrder) -> CosmosM
         route: InjectiveRoute::Exchange,
         msg_data: InjectiveMsg::CreateSpotMarketOrder { sender, order },
     }
-        .into()
+    .into()
 }
 
 pub fn create_derivative_market_order_msg(sender: String, order: DerivativeOrder) -> CosmosMsg<InjectiveMsgWrapper> {
@@ -151,10 +155,16 @@ pub fn create_derivative_market_order_msg(sender: String, order: DerivativeOrder
         route: InjectiveRoute::Exchange,
         msg_data: InjectiveMsg::CreateDerivativeMarketOrder { sender, order },
     }
-        .into()
+    .into()
 }
 
-pub fn create_increase_position_margin_msg(sender: String, source_subaccount_id: String, destination_subaccount_id: String, market_id: String, amount: Coin) -> CosmosMsg<InjectiveMsgWrapper> {
+pub fn create_increase_position_margin_msg(
+    sender: String,
+    source_subaccount_id: String,
+    destination_subaccount_id: String,
+    market_id: String,
+    amount: Coin,
+) -> CosmosMsg<InjectiveMsgWrapper> {
     InjectiveMsgWrapper {
         route: InjectiveRoute::Exchange,
         msg_data: InjectiveMsg::IncreasePositionMargin {
@@ -165,10 +175,15 @@ pub fn create_increase_position_margin_msg(sender: String, source_subaccount_id:
             amount,
         },
     }
-        .into()
+    .into()
 }
 
-pub fn create_liquidate_position_msg(sender: String, subaccount_id: String, market_id: String, order: Option<DerivativeOrder>) -> CosmosMsg<InjectiveMsgWrapper> {
+pub fn create_liquidate_position_msg(
+    sender: String,
+    subaccount_id: String,
+    market_id: String,
+    order: Option<DerivativeOrder>,
+) -> CosmosMsg<InjectiveMsgWrapper> {
     InjectiveMsgWrapper {
         route: InjectiveRoute::Exchange,
         msg_data: InjectiveMsg::LiquidatePosition {
@@ -178,18 +193,15 @@ pub fn create_liquidate_position_msg(sender: String, subaccount_id: String, mark
             order,
         },
     }
-        .into()
+    .into()
 }
 
 pub fn create_register_as_dmm_msg(sender: String, dmm_account: String) -> CosmosMsg<InjectiveMsgWrapper> {
     InjectiveMsgWrapper {
         route: InjectiveRoute::Exchange,
-        msg_data: InjectiveMsg::RegisterAsDMM {
-            sender,
-            dmm_account,
-        },
+        msg_data: InjectiveMsg::RegisterAsDMM { sender, dmm_account },
     }
-        .into()
+    .into()
 }
 
 pub fn create_batch_update_orders_msg(
@@ -215,6 +227,5 @@ pub fn create_batch_update_orders_msg(
             derivative_orders_to_create,
         },
     }
-        .into()
+    .into()
 }
-
