@@ -5,7 +5,7 @@ use serde::{Deserialize, Serialize};
 use crate::{
     derivative::EffectivePosition, derivative::TrimmedDerivativeLimitOrder, derivative_market::FullDerivativeMarket,
     derivative_market::PerpetualMarketFunding, derivative_market::PerpetualMarketInfo, exchange::Deposit, route::InjectiveRoute,
-    spot::TrimmedSpotLimitOrder, spot_market::FullSpotMarket,
+    spot::TrimmedSpotLimitOrder, spot_market::FullSpotMarket, Position,
 };
 use cosmwasm_std::CustomQuery;
 
@@ -39,6 +39,10 @@ pub enum InjectiveQuery {
     SubaccountPositions {
         subaccount_id: String,
     },
+    SubaccountPositionInMarket {
+        market_id: String,
+        subaccount_id: String,
+    },
     SubaccountEffectivePositionInMarket {
         market_id: String,
         subaccount_id: String,
@@ -77,6 +81,11 @@ pub struct SubaccountEffectivePositionInMarketResponse {
     pub state: Option<EffectivePosition>,
 }
 
+#[derive(Serialize, Deserialize, Clone, Debug, PartialEq, JsonSchema)]
+pub struct SubaccountPositionInMarketResponse {
+    pub state: Option<Position>,
+}
+
 #[derive(Serialize, Deserialize, Clone, Debug, PartialEq, JsonSchema)]
 pub struct PerpetualMarketInfoResponse {
     pub info: Option<PerpetualMarketInfo>,
